# queky

### Instalestion
`pip install queky`

### Usage:
1. Get your gemini api key from [here](https://aistudio.google.com/app/apikey).
2. Open terminal and run the command `pip install queky`
3. Type `qk` and press enter to activate the tool.
4. Paste the gemini api key (only asked for the first time).
5. Now copy your questions and paste them in the terminal window by just pressing the enter key.
7. You should receive your answers.